pub struct AuditEvent { /* private fields */ }Expand description
Audit log record.
An audit log record with no associated data is 36 bytes.
When associated data is available an additional 16 bytes is used for events on a vault and 32 bytes for events on a secret and for a move event 64 bytes is used.
The maximum size of a log record is thus 100 bytes.
- 2 bytes for bit flags.
- 8 bytes for the timestamp seconds.
- 4 bytes for the timestamp nanoseconds.
- 2 bytes for the event kind identifier.
- 20 bytes for the public account_id.
- 16, 32 or 64 bytes for the context data (one, two or four UUIDs).
Implementations
Sourceimpl AuditEvent
impl AuditEvent
Sourcepub fn new(
date_time: UtcDateTime,
event_kind: EventKind,
account_id: AccountId,
data: Option<AuditData>,
) -> Self
pub fn new( date_time: UtcDateTime, event_kind: EventKind, account_id: AccountId, data: Option<AuditData>, ) -> Self
Create a new audit log event.
Sourcepub fn account_id(&self) -> &AccountId
pub fn account_id(&self) -> &AccountId
Account identifier for this audit event.
Sourcepub fn time(&self) -> &UtcDateTime
pub fn time(&self) -> &UtcDateTime
Date and time for this audit event.
Sourcepub fn event_kind(&self) -> EventKind
pub fn event_kind(&self) -> EventKind
Event kind for this audit event.